<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el_GR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Σχετικά με την εφαρμογή iTALC</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished">Σχετικά</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished">Συγγραφείς</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation type="unfinished">Μετάφραση</translation>
    </message>
    <message>
        <source>Current language not translated yet (or native English).

If you&apos;re interested in translating iTALC into your local or another language or want to improve an existing translation, please contact an iTALC developer!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished">Άδεια</translation>
    </message>
    <message>
        <source>iTALC - Intelligent Teaching And Learning with Computers

Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccessDialogSlave</name>
    <message>
        <source>Never for this session</source>
        <translation type="unfinished">Πότε για αυτή τη συνεδρία (session)</translation>
    </message>
    <message>
        <source>Always for this session</source>
        <translation type="unfinished">Πάντα για αυτή τη συνεδρία (session)</translation>
    </message>
    <message>
        <source>Confirm desktop access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The user %1 at host %2 wants to access your desktop. Do you want to grant access?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClassroomManager</name>
    <message>
        <source>Classroom-Manager</source>
        <translation type="unfinished">Διαχείριση Τάξης</translation>
    </message>
    <message>
        <source>Use this workspace to manage your computers and classrooms in an easy way.</source>
        <translation type="unfinished">Χρησιμοποιήστε αυτό το χώρο για να διαχειριστείτε εύκολα τους υπολογιστές και τις τάξεις.</translation>
    </message>
    <message>
        <source>This is where computers and classrooms are managed. You can add computers or classrooms by clicking right in this list.</source>
        <translation type="unfinished">Εδώ διαχειριζόσαστε υπολογιστές και τάξεις. Μπορείτε να προσθέσετε υπολογιστές και τάξεις με δεξί κλικ στη λίστα.</translation>
    </message>
    <message>
        <source>Classrooms/computers</source>
        <translation type="unfinished">Τάξεις/υπολογιστές</translation>
    </message>
    <message>
        <source>IP-address</source>
        <translation type="unfinished">Διεύθυνση IP</translation>
    </message>
    <message>
        <source>Usernames</source>
        <translation type="unfinished">Ονόματα χρηστών</translation>
    </message>
    <message>
        <source>Show usernames</source>
        <translation type="unfinished">Εμφάνιση ονομάτων χρηστών</translation>
    </message>
    <message>
        <source>Use the context-menu (right mouse-button) to add/remove computers and/or classrooms.</source>
        <translation type="unfinished">Χρησιμοποιήστε το context-menu (δεξί κλικ ποντικιού) για να προσθέσετε/διαγράψετε υπολογιστές και/ή τάξεις.</translation>
    </message>
    <message>
        <source>Export to text-file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes necessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
        <translation type="unfinished">Πατήστε αυτό το κουμπί για εξαγωγή λίστας υπολογιστών και ονομάτων χρηστών σε ένα αρχείο κειμένου. Μπορείτε να χρησιμοποιήσετε αυτό το αρχείο αργότερα για να συλλέξετε αρχεία μετά τη λήξη μιας εξέτασης. Αυτό είναι αναγκαίο ορισμένες φορές, επειδή κάποιοι χρήστες μπορεί να έχουν τελειώσει και αποσυνδεθεί νωρίτερα και έτσι δε μπορείτε να συλλέξετε τα αρχεία τους στο τέλος της εξέτασης.</translation>
    </message>
    <message>
        <source>Hide teacher computers</source>
        <translation type="unfinished">Απόκρυψη υπολογιστών Δάσκαλου</translation>
    </message>
    <message>
        <source>Show/hide</source>
        <translation type="unfinished">Εμφάνιση/Απόκρυψη</translation>
    </message>
    <message>
        <source>Edit settings</source>
        <translation type="unfinished">Επεξεργασία ρυθμίσεων</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Διαγραφή</translation>
    </message>
    <message>
        <source>Show all computers in classroom</source>
        <translation type="unfinished">Εμφάνιση όλων των υπολογιστών της τάξης</translation>
    </message>
    <message>
        <source>Hide all computers in classroom</source>
        <translation type="unfinished">Απόκρυψη όλων των υπολογιστών της τάξης</translation>
    </message>
    <message>
        <source>Edit name</source>
        <translation type="unfinished">Επεξεργασία ονόματος</translation>
    </message>
    <message>
        <source>Remove classroom</source>
        <translation type="unfinished">Διαγραφή τάξης</translation>
    </message>
    <message>
        <source>Add computer</source>
        <translation type="unfinished">Πρόσθεση υπολογιστή</translation>
    </message>
    <message>
        <source>Add classroom</source>
        <translation type="unfinished">Πρόσθεση τάξης</translation>
    </message>
    <message>
        <source>No configuration-file found</source>
        <translation type="unfinished">Δε βρέθηκε αρχείο εγκατάστασης</translation>
    </message>
    <message>
        <source>Could not open configuration file %1.
You will have to add at least one classroom and computers using the classroom-manager which you&apos;ll find inside the program in the sidebar on the left side.</source>
        <translation type="unfinished">Αδύνατο το άνοιγμα αρχείου εγκατάστασης %1.
Πρέπει να προσθέσετε τουλάχιστον μία τάξη και υπολογιστές με τη Διαχείριση Τάξης που θα βρείτε στην αριστερή μπάρα του προγράμματος.</translation>
    </message>
    <message>
        <source>Error in configuration-file</source>
        <translation type="unfinished">Σφάλμα στο αρχείο εγκατάστασης</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file and have to add all classrooms and computers again.</source>
        <translation type="unfinished">Σφάλμα κατά την επεξεργασία του αρχείου εγκατάστασης %1.
Παρακαλώ διορθώστε το. Διαφορετικά, θα πρέπει να διαγράψετε το αρχείο και να προσθέσετε όλες τις τάξεις και υπολογιστές πάλι.</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file.</source>
        <translation type="unfinished">Σφάλμα κατά την επεξεργασία του αρχείου εγκατάστασης %1.
Παρακαλώ διορθώστε το. Διαφορετικά, θα πρέπει να διαγράψετε το αρχείο.</translation>
    </message>
    <message>
        <source>Select output-file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions for selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Ενέργειες</translation>
    </message>
    <message>
        <source>Actions for %1</source>
        <translation type="unfinished">Ενέργειες για %1</translation>
    </message>
    <message>
        <source>New name for classroom</source>
        <translation type="unfinished">Νέο όνομα για τάξη</translation>
    </message>
    <message>
        <source>Please enter a new name for classroom &quot;%1&quot;.</source>
        <translation type="unfinished">Παρακαλώ εισάγετε νέο όνομα για την τάξη &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Are you sure want to remove classroom &quot;%1&quot;?
All computers in it will be removed as well!</source>
        <translation type="unfinished">Είστε σίγουρος/η ότι θέλετε να διαγράψετε την τάξη &quot;%1&quot;;
Προσοχή! Όλοι οι υπολογιστές της τάξης θα διαγραφούν!</translation>
    </message>
    <message>
        <source>Missing classroom</source>
        <translation type="unfinished">Κενή τάξη</translation>
    </message>
    <message>
        <source>Before adding computers you have to create at least one classroom.
Do you want to create a new classrom now?</source>
        <translation type="unfinished">Πριν την πρόσθεση υπολογιστών πρέπει να δημιουργήσετε τουλάχιστον μία τάξη.
Θέλετε να δημιουργήσετε μία νέα τάξη τώρα;</translation>
    </message>
    <message>
        <source>New classroom</source>
        <translation type="unfinished">Νέα τάξη</translation>
    </message>
    <message>
        <source>Please enter the name of the classroom you want to create.</source>
        <translation type="unfinished">Παρακαλώ εισάγετε το όνομα της τάξης που θέλετε να δημιουργήσετε.</translation>
    </message>
</context>
<context>
    <name>Client</name>
    <message>
        <source>Unknown state</source>
        <translation type="unfinished">Άγνωστη κατάσταση</translation>
    </message>
    <message>
        <source>No user logged in</source>
        <translation type="unfinished">Κανείς χρήστης συνδεδεμένος</translation>
    </message>
    <message>
        <source>Host unreachable</source>
        <translation type="unfinished">Υπολογιστής εκτός σύνδεσης</translation>
    </message>
    <message>
        <source>Demo running</source>
        <translation type="unfinished">Επίδειξη σε εκτέλεση</translation>
    </message>
    <message>
        <source>Desktop locked</source>
        <translation type="unfinished">Επιφάνεια εργασίας κλειδωμένη</translation>
    </message>
</context>
<context>
    <name>ClientAction</name>
    <message>
        <source>Are you sure want logout all users on all visible computers ?</source>
        <translation type="unfinished">Είστε σίγουρος/η ότι θέλετε να αποσυνδεθούν οι χρήστες στους ορατούς υπολογιστές;</translation>
    </message>
    <message>
        <source>Are you sure want logout all users on all selected computers ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation type="unfinished">Αποσύνδεση χρήστη</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all visible computers?</source>
        <translation type="unfinished">Είστε σίγουρος/η ότι θέλετε να επανεκκινήσετε όλους τους ορατούς υπολογιστές;</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all selected computers?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot computers</source>
        <translation type="unfinished">Επανεκκίνηση υπολογιστών</translation>
    </message>
    <message>
        <source>Are you sure want to power down all visible computers?</source>
        <translation type="unfinished">Είστε σίγουρος/η ότι θέλετε να τερματίσουν όλοι οι ορατοί υπολογιστές;</translation>
    </message>
    <message>
        <source>Are you sure want to power down all selected computers?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClientSettingsDialog</name>
    <message>
        <source>Invalid MAC-address</source>
        <translation type="unfinished">Άκυρη MAC-Διεύθυνση</translation>
    </message>
    <message>
        <source>You specified an invalid MAC-address. Either leave the field blank or enter a valid MAC-address (use &quot;:&quot; as separator!).</source>
        <translation type="unfinished">Ορίσατε μια άκυρη MAC-Διεύθυνση. Αφήστε το πεδίο κενό ή εισάγετε μια έγκυρη MAC-Διεύθυνση (χρησιμοποιήστε &quot;:&quot; για διαχωρισμό!)</translation>
    </message>
    <message>
        <source>Client settings</source>
        <translation type="unfinished">Ρυθμίσεις Μαθητή</translation>
    </message>
    <message>
        <source>IP/hostname</source>
        <translation type="unfinished">Διεύθυνση IP/Όνομα υπολογιστή</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;enter an IP-address or hostname under which iTALC can reach the client (use &apos;:&apos; for specifying an optional port-number)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;εισάγετε μια διεύθυνση IP ή ένα όνομα υπολογιστή με το οποίο θα αναζητηθεί ο μαθητής (πληκτρολογήστε &apos;:&apos; για να ορίσετε πιθανό αριθμό πόρτας)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Όνομα</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Optional nickname of the host which is displayed in iTALC.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Προαιρετικό ψευδώνυμο του υπολογιστή που εμφανίζεται στο iTALC.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>MAC address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hardware/MAC-address of client - only used for powering on client&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Υλικό/MAC-διεύθυνση ενός μαθητή - χρησιμοποιείτε μόνο για εκκίνηση υπολογιστή μαθητή&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation type="unfinished">Τάξη</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Τύπος</translation>
    </message>
    <message>
        <source>Student computer</source>
        <translation type="unfinished">Υπολογιστής Μαθητή</translation>
    </message>
    <message>
        <source>Teacher computer</source>
        <translation type="unfinished">Υπολογιστής Δάσκαλου</translation>
    </message>
    <message>
        <source>Other/undefined computer</source>
        <translation type="unfinished">Άλλος/απροσδιόριστος υπολογιστής</translation>
    </message>
    <message>
        <source>Missing IP address/hostname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You didn&apos;t specify an IP address or hostname for the computer!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <source>Interval between updates</source>
        <translation type="unfinished">Διάστημα μεταξύ ενημερώσεων</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set the interval between updates of clients. Higher values result in lower network-traffic and lower CPU-usage on this computer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Ορίστε το διάστημα μεταξύ ενημερώσεων των μαθητών. Υψηλότερες τιμές έχουν ως αποτέλεσμα χαμήλη κίνηση στο δίκτυο και χαμηλή χρήση του επεξεργαστή σε αυτόν τον υπολογιστή.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation type="unfinished">δευτερόλεπτα</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation type="unfinished">Διεπαφή χρήστη</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show balloon-tooltips for toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Απόκρυψη επεξηγήσεων για κουμπιά γραμμών εργαλείων&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Check this option if you&apos;re annoyed by the balloon-tooltips appearing when moving mouse-cursor over toolbar-buttons.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Επιλέξτε εδώ αν σας ενοχλεί η εμφάνιση επεξηγήσεων όταν μετακινείτε το δείκτη ποντικιού πάνω από κουμπιά της γραμμής εργαλείων.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>No balloon-tooltips</source>
        <translation type="unfinished">Απόκρυψη επεξηγήσεων</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show texts on toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Απόκρυψη κειμένου στα κουμπιά γραμμής εργαλείων&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>No texts on toolbar-buttons</source>
        <translation type="unfinished">Απόκρυψη κειμένου στα κουμπιά γραμμών εργαλείων</translation>
    </message>
    <message>
        <source>Your role (needs according keys!)</source>
        <translation type="unfinished">Ο ρόλος σας (απαιτεί σχετικά κλειδιά!)</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can select your role. Only change this if you know what you&apos;re doing. Otherwise you won&apos;t be able to access any clients until you restore your old role.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Επιλέξτε το ρόλο σας. Κάντε αλλαγές εφόσον είστε βέβαιοι. Διαφορετικά δε θα μπορείτε να προσπελάσετε μαθητές μέχρι να επαναφέρετε τον προηγούμενο ρόλο σας.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation type="unfinished">Δάσκαλος</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished">Διαχειριστής</translation>
    </message>
    <message>
        <source>Supporter</source>
        <translation type="unfinished">Βοηθός</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Άλλος</translation>
    </message>
    <message>
        <source>Settings for multi-logon</source>
        <translation type="unfinished">Ρυθμίσεις για πολλαπλή σύνδεση</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="unfinished">Τομέας</translation>
    </message>
    <message>
        <source>Double-click action for client-window</source>
        <translation type="unfinished">Ενέργεια διπλού κλικ σε παράθυρο μαθητή</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set what should happen if you double-click a client-window.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;(new line)p, li { white-space: pre-wrap; }(new line)&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;(new line)&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Ορίστε την ενέργεια που θα εκτελείται όταν κάνετε διπλό κλικ σε παράθυρο μαθητή.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Απομακρυσμένος έλεγχος</translation>
    </message>
    <message>
        <source>View live in fullscreen</source>
        <translation type="unfinished">Ζωντανή παρακολούθηση σε πλήρη οθόνη</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Please note, that some changes won&apos;t take effect until you restart iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Προσοχή: ορισμένες αλλαγές δεν θα ισχύσουν μέχρι να επανεκκινήσετε την εφαρμογή iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ar - العربية</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cs - Česky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>de - Deutsch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>el - Ελληνικά</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>es - Español</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fi - Suomi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fr - Français</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>he - עִבְרִית</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hu - Magyar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>it - Italiano</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nl - Nederlands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nn - Norsk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pl - Polski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_br - Brasileiro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_pt - Português</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ru - Русский</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sk - Slovenský</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sl - Slovenčina</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sv - Svenska</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tr - Türkçe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>uk - Українська</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_cn - 简体字</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_tw - 簡體字</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Your iTALC-configuration</source>
        <translation type="unfinished">Οι Ρυθμίσεις σας</translation>
    </message>
    <message>
        <source>In this workspace you can customize iTALC to fit your needs.</source>
        <translation type="unfinished">Εδώ μπορείτε να παραμετροποίησετε την εφαρμογή iTALC ώστε να ικανοποιεί τις ανάγκες σας.</translation>
    </message>
</context>
<context>
    <name>DecoratedMessageBox</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>DemoClient</name>
    <message>
        <source>iTALC Demo</source>
        <translation type="unfinished">iTALC Επίδειξη</translation>
    </message>
</context>
<context>
    <name>ItalcCoreServer</name>
    <message>
        <source>Authentication error</source>
        <translation type="unfinished">Σφάλμα ταυτοποίησης</translation>
    </message>
    <message>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation type="unfinished">Κάποιος/α (IP: %1) προσπάθησε να εισέλθει στον υπολογιστή αλλά δεν ταυτοποιήθηκε επιτυχώς!</translation>
    </message>
</context>
<context>
    <name>ItalcVncConnection</name>
    <message>
        <source>VNC authentication failed because of too many authentication tries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VNC authentication failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VNC server closed connection.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyFileAssistant</name>
    <message>
        <source>iTALC Access Key Assistant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create/import iTALC access keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This assistant will help you to create or import iTALC access keys.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How does it work?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC access keys consist of two parts belonging together, a private and a public key part.

Using the private key part, users on the master computer will be able to access client computers. It is important that only authorized users have read access to the private key file.

The public key part is used on the client computers to verify that any incoming connection request is authorized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assistant mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please choose whether to create new access keys or import a public key on a client.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create new access keys (master computer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>assistantModeButtonGroup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import public key (client computer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select user role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select a user role for which to create or import the access keys:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation type="unfinished">Δάσκαλος</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished">Διαχειριστής</translation>
    </message>
    <message>
        <source>Support team member</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Άλλος</translation>
    </message>
    <message>
        <source>User roles allow using multiple access keys in parallel. For example there can be different teacher access keys for each classroom while the support access keys are the same for the whole school.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export public key part (master computer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use custom destination directory for access keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please specify the location of the public access key to be imported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following actions will be taken:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Create new access keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Import public access key from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;unknown&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Write access key(s) to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Export public key to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>• Configure for user role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select directory in which to export the public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key files (*.key.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid public key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected file does not contain a valid public iTALC access key!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access key creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove previously existing file %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed exporting public access key from %1 to %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access keys were created and written successfully to %1 and %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while creating the access keys. You probably are not permitted to write to the selected directories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while importing the public access key. You probably are not permitted to read the source key or to write the destination file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The public key was successfully imported to %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>screen lock</source>
        <translation type="unfinished">Κλείδωμα οθόνης</translation>
    </message>
</context>
<context>
    <name>LogonGroupEditor</name>
    <message>
        <source>Logon group editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please add the groups whose members should be allowed to access computers in your iTALC network.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Groups with iTALC privileges</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>Actions</source>
        <translation type="unfinished">Ενέργειες</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>General</source>
        <translation type="unfinished">Γενικά</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Τερματισμός</translation>
    </message>
    <message>
        <source>iTALC Management Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Additional arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log file directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only critical messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors and critical messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings and errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information, warnings and errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debug messages and everything else</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit log file size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear all log files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Desktop capturing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable capturing of layered (semi-transparent) windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low accuracy (turbo mode)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Core server port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo server port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable firewall exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Personal configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snapshots</source>
        <translation type="unfinished">Στιγμιότυπα</translation>
    </message>
    <message>
        <source>Authentication methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access key management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logon settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save settings into file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save settings into file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L&amp;oad settings from file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Σχετικά με την εφαρμογή iTALC</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC Management Console %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load settings from file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save settings to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsaved settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are unsaved settings. Quit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration not writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The local configuration backend reported that the configuration is not writable! Please run the iTALC Management Console with higher privileges.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All settings were applied successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while applying settings!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC</source>
        <translation type="unfinished">iTALC</translation>
    </message>
    <message>
        <source>No write access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not read/write or create directory %1! For running iTALC, make sure you&apos;re permitted to create or write this directory.</source>
        <translation type="unfinished">Αδύνατη η ανάγνωση/εγγραφή ή δημιουργία φακέλου στο %1! Για να εκτελέσετε την εφαρμογή iTALC, παρακαλώ βεβαιωθείτε ότι επιτρέπεται να δημιουργήσετε/γράψετε αρχεία σε αυτό τον φάκελο.</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation type="unfinished">Τάξη</translation>
    </message>
    <message>
        <source>Switch classroom</source>
        <translation type="unfinished">Αλλαγη τάξης</translation>
    </message>
    <message>
        <source>Click this button to open a menu where you can choose the active classroom.</source>
        <translation type="unfinished">Πατήστε αυτό το κουμπί για να επιλέξετε την ενεργή τάξη.</translation>
    </message>
    <message>
        <source>Click on this button, to switch between classrooms.</source>
        <translation type="unfinished">Πατήστε το κουμπί για να μεταβείτε σε άλλες τάξεις.</translation>
    </message>
    <message>
        <source>Overview mode</source>
        <translation type="unfinished">Κατάσταση επισκόπησης</translation>
    </message>
    <message>
        <source>Overview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the default mode in iTALC and allows you to have an overview over all visible computers. Also click on this button for unlocking locked workstations or for leaving demo-mode.</source>
        <translation type="unfinished">Αυτή είναι η προεπιλεγμένη κατάσταση στην εφαρμογή iTALC και σας επιτρέπει να έχετε μια επισκόπηση όλων των ορατών υπολογιστών. Πατήστε αυτό το κουμπί για να ξεκλειδώσετε κλειδωμένους υπολογιστές ή να τερματίσετε την κατάσταση επίδειξης.</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen Demo</source>
        <translation type="unfinished">Επίδειξη Πλήρους Οθόνης</translation>
    </message>
    <message>
        <source>Stop Demo</source>
        <translation type="unfinished">Τερματισμός Επίδειξης</translation>
    </message>
    <message>
        <source>In this mode your screen is being displayed on all shown computers. Furthermore the users aren&apos;t able to do something else as all input devices are locked in this mode.</source>
        <translation type="unfinished">Σε αυτή την κατάσταση η οθόνη σας παρουσιάζεται σε όλους τους ορατούς υπολογιστές. Επιπλέον οι χρήστες δε μπορούν να κάνουν τίποτα άλλο καθώς οι συσκευές εισόδου είναι κλειδωμένες.</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Demo</source>
        <translation type="unfinished">Επίδειξη Παραθύρου</translation>
    </message>
    <message>
        <source>In this mode your screen being displayed in a window on all shown computers. The users are able to switch to other windows and thus can continue to work.</source>
        <translation type="unfinished">Σε αυτή την κατάσταση η οθόνη σας παρουσίαζεται σε όλους τους ορατούς υπολογιστές. Οι χρήστες μπορούν να μεταβούν σε άλλα παράθυρα και να συνεχίσουν την εργασία τους.</translation>
    </message>
    <message>
        <source>Lock/unlock desktops</source>
        <translation type="unfinished">Κλείδωμα/Ξεκλείδωμα επιφάνειας εργασίας</translation>
    </message>
    <message>
        <source>Lock all</source>
        <translation type="unfinished">Κλείδωμα όλων</translation>
    </message>
    <message>
        <source>Unlock all</source>
        <translation type="unfinished">Ξεκλείδωμα όλων</translation>
    </message>
    <message>
        <source>To have all user&apos;s full attention you can lock their desktops using this button. In this mode all input devices are locked and the screen is black.</source>
        <translation type="unfinished">Για να έχετε την προσοχή των χρηστών μπορείτε να κλειδώσετε την επιφάνεια εργασίας με αυτό το κουμπί. Όλες οι συσκευές εισόδου κλειδώνονται και η οθόνη γίνεται μαύρη.</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation type="unfinished">Αποστολή μηνύματος κειμένου</translation>
    </message>
    <message>
        <source>Text message</source>
        <translation type="unfinished">Μήνυμα κειμένου</translation>
    </message>
    <message>
        <source>Use this button to send a text message to all users e.g. to tell them new tasks etc.</source>
        <translation type="unfinished">Χρησιμοποιήστε αυτό το κουμπί για να στείλετε ένα μήνυμα κειμένου σε όλους τους χρήστες, π.χ. για να τους ανακοινώσετε μια νέα εργασία κλπ.</translation>
    </message>
    <message>
        <source>Power on computers</source>
        <translation type="unfinished">Εκκίνηση υπολογιστών</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation type="unfinished">Εκκίνηση</translation>
    </message>
    <message>
        <source>Click this button to power on all visible computers. This way you do not have to turn on each computer by hand.</source>
        <translation type="unfinished">Πατήστε αυτό το κουμπί για να εκκινήσετε όλους τους ορατούς υπολογιστές. Έτσι αποφεύγετε να εκκινήσετε κάθε υπολογιστή χειροκίνητα.</translation>
    </message>
    <message>
        <source>Power down computers</source>
        <translation type="unfinished">Τερματισμός υπολογιστών</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation type="unfinished">Τερματισμός</translation>
    </message>
    <message>
        <source>To power down all shown computers (e.g. after the lesson has finished) you can click this button.</source>
        <translation type="unfinished">Πατήστε αυτό το κουμπί για να τερματίσετε όλους τους υπολογιστές που εμφανίζονται (π.χ. μετά τη λήξη του μαθήματος).</translation>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Direct support</source>
        <translation type="unfinished">Άμεση βοήθεια</translation>
    </message>
    <message>
        <source>If you need to support someone at a certain computer you can click this button and enter the according hostname or IP afterwards.</source>
        <translation type="unfinished">Αν πρέπει να βοηθήσετε κάποιον/α σε ένα συγκεκριμένο υπολογιστή, πατήστε αυτό το κουμπί και εισάγετε το όνομα ή τηn IP διεύθυνση υπολογιστή.</translation>
    </message>
    <message>
        <source>Adjust/align</source>
        <translation type="unfinished">Προσαρμογή/Ευθυγράμμιση</translation>
    </message>
    <message>
        <source>Adjust windows and their size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When clicking this button the biggest possible size for the client-windows is adjusted. Furthermore all windows are aligned.</source>
        <translation type="unfinished">Πατώντας αυτό το κουμπί προσαρμόζεται το παράθυρο των μαθητών στο μεγαλύτερο δυνατό μέγεθος. Επιπλέον, όλα τα παράθυρα ευθυγραμμίζονται.</translation>
    </message>
    <message>
        <source>Auto view</source>
        <translation type="unfinished">Αυτόματη προβολή</translation>
    </message>
    <message>
        <source>Auto re-arrange windows and their size</source>
        <translation type="unfinished">Αυτόματη αναπροσαρμογή παραθύρων και του μεγέθους τους</translation>
    </message>
    <message>
        <source>When clicking this button all visible windows are re-arranged and adjusted.</source>
        <translation type="unfinished">Πατώντας αυτό το κουμπί όλα τα παράθυρα των μαθητών αναπροσαρμόζονται στο προεπιλεγμένο μέγεθος και ευθυγραμμίζονται.</translation>
    </message>
    <message>
        <source>iTALC Master Control</source>
        <translation type="unfinished">iTALC Πίνακας Ελέγχου</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Απομακρυσμένος έλεγχος</translation>
    </message>
    <message>
        <source>Could not modify the autostart property for the iTALC Service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not modify the service arguments for the iTALC Service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not change the firewall configuration for the iTALC Service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable desktop switching for screen lock (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log to standard error output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log to Windows event log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VNC reflector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC 1 demo server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multithreading (can be enabled when using the VNC reflector backend)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable HTTP server which provides a JavaViewer applet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTTP server port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow connections from localhost only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key file authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ACL-based logon authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key file base directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private key file base directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Launch key file assistant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can configure iTALC to ask the user for permission to access the desktop when using certain authentication methods.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logon authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow same user to access desktop without confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging iTALC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When encountering bugs or other misbehaviour in iTALC it is important to inform the developers about them, so that the bugs can be fixed in future releases. This page allows you to submit a helpful bug report easily.

If the bug is not reproducible, skip step 1) - 3).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear the logfiles in the &quot;General&quot; section.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In the &quot;General&quot; section set the log level to &quot;Debug messages and everything else&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat the actions leading to the bug or misbehaviour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click the following button and save the file to a known location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate bug report archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to the &lt;a href=&quot;http://sourceforge.net/tracker/?group_id=132465&amp;amp;atid=724375&quot;&gt;iTALC bug tracker&lt;/a&gt;, open a new bug, describe what you did in step 3) and attach the file you saved in step 4).&lt;/p&gt;
&lt;br/&gt;
&lt;br/&gt;
Note: if the bug involves both a master and client computer, attach bug report archives for both computers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart iTALC Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All settings were saved successfully. In order to take effect the iTALC service needs to be restarted. Restart it now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The iTALC service needs to be stopped temporarily in order to remove the log files. Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log files cleared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All log files were cleared successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove all log files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logon authentication test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication with provided credentials was successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication with provided credentials failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save bug report archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC bug report archive (*.ibra.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC bug report archive saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An iTALC bug report archive has been saved to %1. It includes iTALC log files and information about your operating system. You can attach it to a bug report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not contact iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not contact the local iTALC service. It is likely that you entered wrong credentials or key files are not set up properly. Try again or contact your administrator for solving this problem using the iTALC Management Console.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication impossible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No authentication key files were found or your current ones are outdated. Please create new key files using the iTALC Management Console. Alternatively set up logon authentication using the iTALC Management Console. Otherwise you won&apos;t be able to access computers using iTALC.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Poll full screen (leave this enabled per default)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageBoxSlave</name>
    <message>
        <source>Message from teacher</source>
        <translation type="unfinished">Μήνυμα από τον Δάσκαλο</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Welcome to iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Καλώσήλθατε στο iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Here you see the working-bar which contains several buttons. Each button is connected to a workspace. Just take a look at the available workspaces by clicking on the corresponding button.</source>
        <translation type="unfinished">Εδώ φαίνεται η γραμμή εργασίας με αρκετά κουμπιά. Κάθε κουμπί συνδέεται με μια περιοχή εργασίας. Δείτε τις διαθέσιμες περιοχές πατώντας τα αντίστοιχα κουμπιά.</translation>
    </message>
    <message>
        <source>Using the classroom-manager you can manage your classrooms and computers. You can also see which users are logged in.</source>
        <translation type="unfinished">Χρησιμοποιώντας το διαχειριστή τάξης μπορείτε να διαχειριστείτε τάξεις και υπολογιστές, καθώς επίσης να δείτε ποιοι χρήστες συνδέθηκαν.</translation>
    </message>
    <message>
        <source>The snapshot-workspace is a very useful tool. It let&apos;s you manage the snapshots you made.</source>
        <translation type="unfinished">Η περιοχή στιγμιοτύπων είναι ένα πολύ χρήσιμο εργαλείο για τη διαχείριση των φωτογραφιών που δημιουργήσατε.</translation>
    </message>
    <message>
        <source>Of course you can configure iTALC. This is usually done using the configuration-workspace.</source>
        <translation type="unfinished">Φυσικά μπορείτε να ρυθμίσετε την εφαρμογή iTALC από την περιοχή ρυθμίσεων.</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation type="unfinished">Σχετικά με την εφαρμογή iTALC</translation>
    </message>
</context>
<context>
    <name>OverviewWidget</name>
    <message>
        <source>Overview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some basic information on iTALC and how to use it.</source>
        <translation type="unfinished">Βασικές πληροφορίες για την εφαρμογή iTALC και πως να τη χρησιμοποιήσετε.</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Please enter your username and password in order to access iTALC clients.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Κωδικός</translation>
    </message>
    <message>
        <source>iTALC Logon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>Αδυναμία καταχώρισης της υπηρεσίας &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>Η Διαχείριση Υπηρεσιών (Service Control Manager) δεν ανταποκρίνεται (έχετε τα απαραίτητα δικαιώματα;!) - Η υπηρεσία &apos;%1&apos; δεν καταχωρήθηκε.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>Η υπηρεσία &apos;%1&apos; έχει ήδη καταχωρηθεί.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>Η υπηρεσία &apos;%1&apos; δε μπορεί να καταχωρηθεί.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>Η υπηρεσία &apos;%1&apos; καταχωρήθηκε επιτυχώς.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>Η υπηρεσία &apos;%1&apos; δε μπορεί να τερματιστεί.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>Η υπηρεσία &apos;%1&apos; έχει αποκαταχωρηθεί.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>Η υπηρεσία &apos;%1&apos; δεν είναι καταχωρημένη και για αυτό δε μπορεί να αποκαταχωρηθεί.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>Η υπηρεσία &apos;%1&apos; δε μπορεί να αποκαταχωρηθεί.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>Η υπηρεσία &apos;%1&apos; δε βρέθηκε.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>Η Διαχείριση Υπηρεσιών (Service Control Manager) δεν ανταποκρίνεται (έχετε τα απαραίτητα δικαιώματα;!) - Η υπηρεσία &apos;%1&apos; δεν αποκαταχωρήθηκε.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>Η Διαχείριση Υπηρεσιών (Service Control Manager) δεν ανταποκρίνεται (έχετε τα απαραίτητα δικαιώματα;!) - Η υπηρεσία &apos;%1&apos; δεν τερματίστηκε.</translation>
    </message>
    <message>
        <source>iTALC Client %1 on %2:%3</source>
        <translation>iTALC Μαθητής %1:%2:%3</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidget</name>
    <message>
        <source>View live (%1 @ %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote control (%1 @ %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown user</source>
        <translation type="unfinished">Άγνωστος χρήστης</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidgetToolBar</name>
    <message>
        <source>View only</source>
        <translation type="unfinished">Προβολή μόνο</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Απομακρυσμένος έλεγχος</translation>
    </message>
    <message>
        <source>Lock student</source>
        <translation type="unfinished">Κλείδωμα μαθητή</translation>
    </message>
    <message>
        <source>Unlock student</source>
        <translation type="unfinished">Ξεκλείδωμα μαθητή</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation type="unfinished">Στιγμιότυπο</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="unfinished">Παράθυρο</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Τερματισμός</translation>
    </message>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished">Σύνδεση με %1</translation>
    </message>
    <message>
        <source>Connected.</source>
        <translation type="unfinished">Συνδέθηκε.</translation>
    </message>
</context>
<context>
    <name>RemoteLogonDialog</name>
    <message>
        <source>Remote logon</source>
        <translation type="unfinished">Απομακρυσμένος έλεγχος</translation>
    </message>
    <message>
        <source>Use the fields below to enter the username, password and optional the domain name. These information will be used to logon the computer(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Κωδικός</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="unfinished">Τομέας</translation>
    </message>
</context>
<context>
    <name>RunCommandsDialog</name>
    <message>
        <source>Run commands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the commands to run on the selected client(s). You can separate multiple commands by line.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Snapshot</name>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation type="unfinished">Αδύνατη η δημιουργία στιγμιοτύπου. Ο φάκελος %1 δεν υπάρχει και δε μπορεί να δημιουργηθεί.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation type="unfinished">Στιγμιότυπο</translation>
    </message>
</context>
<context>
    <name>SnapshotList</name>
    <message>
        <source>Snapshots</source>
        <translation type="unfinished">Στιγμιότυπα</translation>
    </message>
    <message>
        <source>Simply manage the snapshots you made using this workspace.</source>
        <translation type="unfinished">Διαχειριστείτε τις φωτογραφίες που δημιουργήσατε σε αυτή την περιοχή εργασίας.</translation>
    </message>
</context>
<context>
    <name>Snapshots</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;All snapshots you made are listed here. You can make snapshots by selecting the according entry in the context-menu of a client-window. These snapshosts can be managed using the buttons below.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Όλες οι φωτογραφίες που δημιουργήσατε φαίνονται εδώ. Μπορείτε να δημιουργήσετε φωτογραφίες επιλέγοντας τη σχετική εντολή στο μενού συντόμευσης ενός παραθύρου μαθητή. Οι φωτογραφίες διαχειρίζονται με τα ακόλουθα κουμπιά.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished">Χρήστης:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished">Υπολογιστής:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation type="unfinished">Ημερομηνία:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="unfinished">Ώρα:</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SupportDialog</name>
    <message>
        <source>Support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the IP address or the name of the host to which you want to connect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextMessageDialog</name>
    <message>
        <source>Send text message</source>
        <translation type="unfinished">Αποστολή μηνύματος κειμένου</translation>
    </message>
    <message>
        <source>Use the field below to type your message which will be sent to all selected users.</source>
        <translation type="unfinished">Γράψτε το μήνυμά σας στο παρακάτω πεδίο για να το στείλετε στους επιλεγμένους χρήστες.</translation>
    </message>
</context>
<context>
    <name>VncView</name>
    <message>
        <source>Establishing connection to %1 ...</source>
        <translation type="unfinished">Σύνδεση με %1 ...</translation>
    </message>
</context>
<context>
    <name>clientMenu</name>
    <message>
        <source>Overview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locked display</source>
        <translation type="unfinished">Κλειδωμένη οθόνη</translation>
    </message>
    <message>
        <source>View live</source>
        <translation type="unfinished">Ζωντανή παρακολούθηση</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation type="unfinished">Απομακρυσμένος έλεγχος</translation>
    </message>
    <message>
        <source>Let student show demo</source>
        <translation type="unfinished">Επίδειξη οθόνης μαθητή</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation type="unfinished">Αποστολή μηνύματος κειμένου</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation type="unfinished">Αποσύνδεση χρήστη</translation>
    </message>
    <message>
        <source>Take a snapshot</source>
        <translation type="unfinished">Βγάλε ένα στιγμιότυπο</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation type="unfinished">Εκκίνηση</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished">Επανεκκίνηση</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation type="unfinished">Τερματισμός</translation>
    </message>
    <message>
        <source>Execute commands</source>
        <translation type="unfinished">Εκτέλεση εντολών</translation>
    </message>
</context>
</TS>
